==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/OffsettableWeekExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
/**
 * @hidden
 */
export let OffsettableWeekExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class OffsettableWeekExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (OffsettableWeekExpressionDescriptionMetadata.a == null) {
                OffsettableWeekExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                OffsettableWeekExpressionDescriptionMetadata.c(OffsettableWeekExpressionDescriptionMetadata.a);
            }
            if (a.j(OffsettableWeekExpressionDescriptionMetadata.a)) {
                return;
            }
            a.y(OffsettableWeekExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            OffsettableWeekExpressionDescriptionMetadata.b(a);
            a.z("OffsettableWeekExpression", OffsettableWeekExpressionDescriptionMetadata.a);
        }
    }
    OffsettableWeekExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(OffsettableWeekExpressionDescriptionMetadata, 'OffsettableWeekExpressionDescriptionMetadata');
    OffsettableWeekExpressionDescriptionMetadata.a = null;
    return OffsettableWeekExpressionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/OffsettableWeekExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
/**
 * @hidden
 */
export let OffsettableWeekExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class OffsettableWeekExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (OffsettableWeekExpressionDescriptionMetadata.a == null) {
                OffsettableWeekExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                OffsettableWeekExpressionDescriptionMetadata.c(OffsettableWeekExpressionDescriptionMetadata.a);
            }
            if (a.k(OffsettableWeekExpressionDescriptionMetadata.a)) {
                return;
            }
            a.aa(OffsettableWeekExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            OffsettableWeekExpressionDescriptionMetadata.b(a);
            a.ab("OffsettableWeekExpression", OffsettableWeekExpressionDescriptionMetadata.a);
        }
    }
    OffsettableWeekExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(OffsettableWeekExpressionDescriptionMetadata, 'OffsettableWeekExpressionDescriptionMetadata');
    OffsettableWeekExpressionDescriptionMetadata.a = null;
    return OffsettableWeekExpressionDescriptionMetadata;
})();
